[前][次][番号順一覧][スレッド一覧]

ruby-changes:35755

From: odaira <ko1@a...>
Date: Wed, 8 Oct 2014 04:40:20 +0900 (JST)
Subject: [ruby-changes:35755] odaira:r47837 (trunk): test/ruby/test_process.rb (TestProcess#test_setsid): AIX does not allow Process::getsid(pid) when pid is in a different session

odaira	2014-10-08 04:40:13 +0900 (Wed, 08 Oct 2014)

  New Revision: 47837

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=47837

  Log:
    test/ruby/test_process.rb (TestProcess#test_setsid): AIX does not allow Process::getsid(pid) when pid is in a different session

  Modified files:
    trunk/ChangeLog
    trunk/test/ruby/test_process.rb
Index: ChangeLog
===================================================================
--- ChangeLog	(revision 47836)
+++ ChangeLog	(revision 47837)
@@ -1,3 +1,9 @@ https://github.com/ruby/ruby/blob/trunk/ChangeLog#L1
+Wed Oct  8 04:38:29 2014  Rei Odaira  <Rei.Odaira@g...>
+
+	* test/ruby/test_process.rb (TestProcess#test_setsid): AIX
+	  does not allow Process::getsid(pid) when pid is in a
+	  different session.
+
 Wed Oct  8 04:33:04 2014  Rei Odaira  <Rei.Odaira@g...>
 
 	* test/ruby/test_rubyoptions.rb (TestRubyOptions#test_encoding):
Index: test/ruby/test_process.rb
===================================================================
--- test/ruby/test_process.rb	(revision 47836)
+++ test/ruby/test_process.rb	(revision 47837)
@@ -1676,9 +1676,9 @@ class TestProcess < Test::Unit::TestCase https://github.com/ruby/ruby/blob/trunk/test/ruby/test_process.rb#L1676
   def test_setsid
     return unless Process.respond_to?(:setsid)
     return unless Process.respond_to?(:getsid)
     # OpenBSD doesn't allow Process::getsid(pid) when pid is in
     # different session.
-    return if /openbsd/ =~ RUBY_PLATFORM
+    return if /openbsd|aix/ =~ RUBY_PLATFORM
 
     IO.popen([RUBY, "-e", <<EOS]) do|io|
 	Marshal.dump(Process.getsid, STDOUT)
@@ -1676,9 +1676,9 @@ class TestProcess < Test::Unit::TestCase https://github.com/ruby/ruby/blob/trunk/test/ruby/test_process.rb#L1676
     return unless Process.respond_to?(:setsid)
     return unless Process.respond_to?(:getsid)
-    # OpenBSD doesn't allow Process::getsid(pid) when pid is in
+    # OpenBSD and AIX don't allow Process::getsid(pid) when pid is in
     # different session.

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]